#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-t3iMvUOsvaKZsdEuTF3no
key:                  pandoc-types-1.23.1-t3iMvUOsvaKZsdEuTF3no
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  72528fd53a5ff4e97d988f8ec2390380
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pandoc-types-1.23.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-t3iMvUOsvaKZsdEuTF3no
depends:
    QuickCheck-2.15.0.1-I3nwcrcTWe7LuyBFdGic3t
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    ghc-prim-0.10.0 syb-0.7.3-9nTxFCe6QUcL36iCSC2LiM text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

